FlutterAdvertisingIdPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterAdvertisingIdPlatform
Implementers

Constructors

FlutterAdvertisingIdPlatform()
Constructs a FlutterAdvertisingIdPlatform.

Properties

authorizationStatus → Future<AdTrackingAuthorizationStatus>
no setter
hashCode → int
The hash code for this object.
no setterinherited
limitAdTrackingEnabled → Future<bool?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAdvertisingId([bool requestTrackingAuthorization = false]) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterAdvertisingIdPlatform
The default instance of FlutterAdvertisingIdPlatform to use.
getter/setter pair